@@ -2,6 +2,9 @@
 
 """Top-level package for BTB."""
 
+from btb.session import BTBSession
+
 __author__ = """MIT Data To AI Lab"""
 __email__ = 'dailabmit@gmail.com'
-__version__ = '0.3.4'
+__version__ = '0.3.6'
+__all__ = ('BTBSession', )
